@@ -4,6 +4,7 @@
  */
 
 use cargo_rdme::find_first_file_in_ancestors;
+use cargo_rdme::transform::{IntralinksConfig, IntralinksDocsRsConfig};
 use std::ffi::OsString;
 use std::path::{Path, PathBuf};
 use std::str::FromStr;
@@ -13,10 +14,7 @@ const PROJECT_NAME: &str = env!("CARGO_PKG_NAME");
 const VERSION: &str = env!("CARGO_PKG_VERSION");
 
 #[derive(Debug)]
-pub struct InvalidOptValue {
-    got: String,
-    expected: &'static [&'static str],
-}
+pub struct InvalidOptValue;
 
 #[derive(PartialEq, Eq, Debug, Clone, Copy)]
 pub enum LineTerminatorOpt {
@@ -43,7 +41,7 @@ impl FromStr for LineTerminatorOpt {
             "auto" => Ok(LineTerminatorOpt::Auto),
             "lf" => Ok(LineTerminatorOpt::Lf),
             "crlf" => Ok(LineTerminatorOpt::CrLf),
-            _ => Err(InvalidOptValue { got: s.to_owned(), expected: LineTerminatorOpt::VALUES }),
+            _ => Err(InvalidOptValue),
         }
     }
 }
@@ -69,6 +67,7 @@ pub struct CmdOptions {
     line_terminator: Option<LineTerminatorOpt>,
     check: bool,
     no_fail_on_warnings: bool,
+    intralinks_strip_links: bool,
     force: bool,
     readme_path: Option<PathBuf>,
 }
@@ -96,9 +95,8 @@ fn get_cmd_args() -> Vec<OsString> {
 pub fn cmd_options() -> CmdOptions {
     use clap::{App, Arg};
 
-    #[allow(clippy::needless_pass_by_value)]
-    fn validator_entrypoint(value: String) -> Result<(), String> {
-        match value.as_str() {
+    fn validator_entrypoint(value: &str) -> Result<(), String> {
+        match value {
             "auto" | "lib" | "bin" => Ok(()),
             v if v.starts_with("bin:") && v.len() > "bin:".len() => Ok(()),
             _ => Err(format!("invalid value \"{}\"", value)),
@@ -108,50 +106,55 @@ pub fn cmd_options() -> CmdOptions {
     let cmd_opts = App::new(PROJECT_NAME)
         .version(VERSION)
         .about("Create the README from your crate’s documentation.")
-        .version_short("v")
+        .mut_arg("version", |a| a.short('v'))
         .arg(
-            Arg::with_name("entrypoint")
+            Arg::new("entrypoint")
                 .long("entrypoint")
                 .help("selects the source code entrypoint of the crate (e.g. auto, lib, bin, bin:<name>)")
                 .takes_value(true)
                 .validator(validator_entrypoint),
         )
         .arg(
-            Arg::with_name("line-terminator")
+            Arg::new("line-terminator")
                 .long("line-terminator")
                 .help("line terminator to use when writing the README file")
                 .takes_value(true)
                 .possible_values(LineTerminatorOpt::VALUES),
         )
         .arg(
-            Arg::with_name("readme-path")
+            Arg::new("readme-path")
                 .long("readme-path")
-                .short("r")
+                .short('r')
                 .help("README file path to use (overrides of what is specified in the project `Cargo.toml`)")
                 .takes_value(true),
         )
         .arg(
-            Arg::with_name("workspace-project")
+            Arg::new("workspace-project")
                 .long("workspace-project")
-                .short("w")
+                .short('w')
                 .help("project to get the documentation from if your are using workspaces")
                 .takes_value(true),
         )
         .arg(
-            Arg::with_name("check")
+            Arg::new("check")
                 .long("check")
-                .short("c")
+                .short('c')
                 .help("checks if the README is up to date"),
         )
         .arg(
-        Arg::with_name("no-fail-on-warnings")
+        Arg::new("no-fail-on-warnings")
             .long("no-fail-on-warnings")
             .help("do not exit with a error status code when checking if the README is up to date"),
         )
         .arg(
-            Arg::with_name("force")
+        Arg::new("intralinks-strip-links")
+            .long("intralinks-strip-links")
+            .help("remove the intralinks"),
+    )
+        .arg(
+            Arg::new("force")
                 .long("force")
-                .short("f")
+                .short('f')
                 .help("force README update, even when there are uncommitted changes"),
         )
         .get_matches_from(get_cmd_args());
@@ -187,6 +190,7 @@ pub fn cmd_options() -> CmdOptions {
         line_terminator,
         check: cmd_opts.is_present("check"),
         no_fail_on_warnings: cmd_opts.is_present("no-fail-on-warnings"),
+        intralinks_strip_links: cmd_opts.is_present("intralinks-strip-links"),
         force: cmd_opts.is_present("force"),
         readme_path,
     }
@@ -210,6 +214,7 @@ pub struct ConfigFileOptions {
     workspace_project: Option<String>,
     entrypoint: Option<EntrypointOpt>,
     readme_path: Option<PathBuf>,
+    intralinks: Option<IntralinksConfig>,
 }
 
 fn config_file_options_from_str(
@@ -251,7 +256,30 @@ fn config_file_options_from_str(
     let readme_path =
         config_toml.get("readme-path").and_then(toml::Value::as_str).map(PathBuf::from);
 
-    Ok(ConfigFileOptions { line_terminator, workspace_project, entrypoint, readme_path })
+    let intralinks_table = config_toml.get("intralinks").and_then(toml::Value::as_table);
+
+    let intralinks_docs_rs_base_url =
+        intralinks_table.and_then(|t| t.get("docs-rs-base-url")).and_then(toml::Value::as_str);
+    let intralinks_docs_rs_version =
+        intralinks_table.and_then(|t| t.get("docs-rs-version")).and_then(toml::Value::as_str);
+    let intralinks_strip_links =
+        intralinks_table.and_then(|t| t.get("strip-links")).and_then(toml::Value::as_bool);
+
+    let intralinks = intralinks_table.map(|_| IntralinksConfig {
+        docs_rs: IntralinksDocsRsConfig {
+            docs_rs_base_url: intralinks_docs_rs_base_url.map(ToOwned::to_owned),
+            docs_rs_version: intralinks_docs_rs_version.map(ToOwned::to_owned),
+        },
+        strip_links: intralinks_strip_links,
+    });
+
+    Ok(ConfigFileOptions {
+        line_terminator,
+        workspace_project,
+        entrypoint,
+        readme_path,
+        intralinks,
+    })
 }
 
 pub fn config_file_options(
@@ -276,6 +304,7 @@ pub struct Options {
     pub no_fail_on_warnings: bool,
     pub force: bool,
     pub readme_path: Option<PathBuf>,
+    pub intralinks: Option<IntralinksConfig>,
 }
 
 #[allow(clippy::needless_pass_by_value)]
@@ -303,12 +332,32 @@ pub fn merge_options(
         readme_path: cmd_options
             .readme_path
             .or_else(|| config_file_options.as_mut().and_then(|c| c.readme_path.take())),
+        intralinks: Some(IntralinksConfig {
+            docs_rs: IntralinksDocsRsConfig {
+                docs_rs_base_url: config_file_options
+                    .as_mut()
+                    .and_then(|c| c.intralinks.as_mut())
+                    .and_then(|il| il.docs_rs.docs_rs_base_url.take()),
+                docs_rs_version: config_file_options
+                    .as_mut()
+                    .and_then(|c| c.intralinks.as_mut())
+                    .and_then(|il| il.docs_rs.docs_rs_version.take()),
+            },
+            strip_links: match cmd_options.intralinks_strip_links {
+                true => Some(true),
+                false => config_file_options
+                    .as_ref()
+                    .and_then(|c| c.intralinks.as_ref())
+                    .and_then(|il| il.strip_links),
+            },
+        }),
     }
 }
 
 #[cfg(test)]
 mod tests {
     use super::*;
+    use cargo_rdme::transform::IntralinksDocsRsConfig;
     use indoc::indoc;
     use pretty_assertions::assert_eq;
 
@@ -322,6 +371,11 @@ mod tests {
             [entrypoint]
             type = "bin"
             bin-name = "baz"
+
+            [intralinks]
+            docs-rs-base-url = "https://internaldocs.rs"
+            docs-rs-version = "1.0.0"
+            strip-links = true
             "#
         };
 
@@ -332,6 +386,13 @@ mod tests {
             entrypoint: Some(EntrypointOpt::BinName("baz".to_owned())),
             line_terminator: Some(LineTerminatorOpt::CrLf),
             readme_path: Some(PathBuf::from("ReAdMe.md")),
+            intralinks: Some(IntralinksConfig {
+                docs_rs: IntralinksDocsRsConfig {
+                    docs_rs_base_url: Some("https://internaldocs.rs".to_owned()),
+                    docs_rs_version: Some("1.0.0".to_owned()),
+                },
+                strip_links: Some(true),
+            }),
         };
 
         assert_eq!(config_file_opts, expected);
@@ -345,6 +406,7 @@ mod tests {
             line_terminator: Some(LineTerminatorOpt::CrLf),
             check: true,
             no_fail_on_warnings: true,
+            intralinks_strip_links: true,
             force: true,
             readme_path: Some(PathBuf::from("rEaDmE.md")),
         };
@@ -353,6 +415,13 @@ mod tests {
             entrypoint: Some(EntrypointOpt::Lib),
             line_terminator: Some(LineTerminatorOpt::Lf),
             readme_path: Some(PathBuf::from("ReAdMe.md")),
+            intralinks: Some(IntralinksConfig {
+                docs_rs: IntralinksDocsRsConfig {
+                    docs_rs_base_url: Some("https://internaldocs.rs".to_owned()),
+                    docs_rs_version: Some("1.0.0".to_owned()),
+                },
+                strip_links: Some(false),
+            }),
         };
 
         let options = merge_options(cmd_options, Some(config_file_options));
@@ -365,6 +434,13 @@ mod tests {
             no_fail_on_warnings: true,
             force: true,
             readme_path: Some(PathBuf::from("rEaDmE.md")),
+            intralinks: Some(IntralinksConfig {
+                docs_rs: IntralinksDocsRsConfig {
+                    docs_rs_base_url: Some("https://internaldocs.rs".to_owned()),
+                    docs_rs_version: Some("1.0.0".to_owned()),
+                },
+                strip_links: Some(true),
+            }),
         };
 
         assert_eq!(options, expected);
