@@ -40,10 +40,23 @@ impl From<module_walker::ModuleWalkError> for IntralinkError {
     }
 }
 
+#[derive(Default, Debug, PartialEq, Eq, Clone)]
+pub struct IntralinksDocsRsConfig {
+    pub docs_rs_base_url: Option<String>,
+    pub docs_rs_version: Option<String>,
+}
+
+#[derive(Default, Debug, PartialEq, Eq, Clone)]
+pub struct IntralinksConfig {
+    pub docs_rs: IntralinksDocsRsConfig,
+    pub strip_links: Option<bool>,
+}
+
 pub struct DocTransformIntralinks<F> {
     crate_name: String,
     entrypoint: PathBuf,
     emit_warning: F,
+    config: IntralinksConfig,
 }
 
 impl<F> DocTransformIntralinks<F>
@@ -54,11 +67,13 @@ where
         crate_name: impl Into<String>,
         entrypoint: impl AsRef<Path>,
         emit_warning: F,
+        config: Option<IntralinksConfig>,
     ) -> DocTransformIntralinks<F> {
         DocTransformIntralinks {
             crate_name: crate_name.into(),
             entrypoint: entrypoint.as_ref().to_path_buf(),
             emit_warning,
+            config: config.unwrap_or_default(),
         }
     }
 }
@@ -77,9 +92,19 @@ where
             return Ok(doc.clone());
         }
 
-        let symbols_type = load_symbols_type(&self.entrypoint, &symbols, &self.emit_warning)?;
-        let new_doc =
-            rewrite_markdown_links(doc, &symbols_type, &self.crate_name, &self.emit_warning);
+        // We only load symbols type information when we need them.
+        let symbols_type = match self.config.strip_links.unwrap_or(false) {
+            false => load_symbols_type(&self.entrypoint, &symbols, &self.emit_warning)?,
+            true => HashMap::new(),
+        };
+
+        let new_doc = rewrite_markdown_links(
+            doc,
+            &symbols_type,
+            &self.crate_name,
+            &self.emit_warning,
+            &self.config,
+        );
 
         Ok(new_doc)
     }
@@ -437,7 +462,12 @@ fn extract_markdown_intralink_symbols(doc: &Doc) -> HashSet<FQIdentifier> {
     symbols
 }
 
-fn documentation_url(symbol: &FQIdentifier, typ: SymbolType, crate_name: &str) -> String {
+fn documentation_url(
+    symbol: &FQIdentifier,
+    typ: SymbolType,
+    crate_name: &str,
+    config: &IntralinksDocsRsConfig,
+) -> String {
     let package_name = crate_name.replace("-", "_");
     let mut path = symbol.path();
 
@@ -448,7 +478,11 @@ fn documentation_url(symbol: &FQIdentifier, typ: SymbolType, crate_name: &str) -
             format!("https://doc.rust-lang.org/stable/{}/", std_crate_name)
         }
         FQIdentifierAnchor::Crate => {
-            format!("https://docs.rs/{}/latest/{}/", crate_name, package_name)
+            let base_url =
+                config.docs_rs_base_url.as_ref().map_or("https://docs.rs", String::as_str);
+            let version = config.docs_rs_version.as_ref().map_or("latest", String::as_str);
+
+            format!("{}/{}/{}/{}/", base_url, crate_name, version, package_name)
         }
     };
 
@@ -480,11 +514,44 @@ fn documentation_url(symbol: &FQIdentifier, typ: SymbolType, crate_name: &str) -
     link
 }
 
+enum MarkdownLinkAction {
+    Link(String),
+    Preserve,
+    Strip,
+}
+
+fn markdown_link(
+    link: &str,
+    link_fragment: &str,
+    link_text: &str,
+    symbols_type: &HashMap<FQIdentifier, SymbolType>,
+    crate_name: &str,
+    emit_warning: &impl Fn(&str),
+    config: &IntralinksConfig,
+) -> MarkdownLinkAction {
+    match FQIdentifier::from_string(link) {
+        Some(symbol) if symbols_type.contains_key(&symbol) => {
+            let typ = symbols_type[&symbol];
+            let new_link = documentation_url(&symbol, typ, crate_name, &config.docs_rs);
+
+            MarkdownLinkAction::Link(format!("[{}]({}{})", link_text, new_link, link_fragment))
+        }
+        Some(symbol) => {
+            emit_warning(&format!("Could not find definition of `{}`.", symbol));
+
+            // This was an intralink, but we were not able to generate a link.
+            MarkdownLinkAction::Strip
+        }
+        _ => MarkdownLinkAction::Preserve,
+    }
+}
+
 fn rewrite_markdown_links(
     doc: &Doc,
     symbols_type: &HashMap<FQIdentifier, SymbolType>,
     crate_name: &str,
     emit_warning: &impl Fn(&str),
+    config: &IntralinksConfig,
 ) -> Doc {
     use crate::transform::utils::ItemOrOther;
 
@@ -495,21 +562,32 @@ fn rewrite_markdown_links(
             ItemOrOther::Item(MarkdownInlineLink { text, link }) => {
                 let (link, fragment): (&str, &str) = split_link_fragment(&link);
 
-                match FQIdentifier::from_string(link) {
-                    Some(symbol) if symbols_type.contains_key(&symbol) => {
-                        let typ = symbols_type[&symbol];
-                        let new_link = documentation_url(&symbol, typ, crate_name);
+                let markdown_link: MarkdownLinkAction = match config.strip_links.unwrap_or(false) {
+                    false => markdown_link(
+                        link,
+                        fragment,
+                        &text,
+                        symbols_type,
+                        crate_name,
+                        emit_warning,
+                        config,
+                    ),
+                    true => match FQIdentifier::from_string(link) {
+                        None => MarkdownLinkAction::Preserve,
+                        Some(_) => MarkdownLinkAction::Strip,
+                    },
+                };
 
-                        new_doc.push_str(&format!("[{}]({}{})", text, new_link, fragment));
+                match markdown_link {
+                    MarkdownLinkAction::Link(markdown_link) => {
+                        new_doc.push_str(&markdown_link);
                     }
-
-                    r => {
-                        if let Some(symbol) = r {
-                            emit_warning(&format!("Could not find definition of `{}`.", symbol));
-                        }
-
+                    MarkdownLinkAction::Preserve => {
                         new_doc.push_str(&format!("[{}]({}{})", text, link, fragment));
                     }
+                    MarkdownLinkAction::Strip => {
+                        new_doc.push_str(&text);
+                    }
                 }
             }
             ItemOrOther::Other(other) => {
@@ -928,22 +1006,31 @@ mod tests {
 
     #[test]
     fn test_documentation_url() {
-        let link = documentation_url(&identifier("crate"), SymbolType::Crate, "foobini");
+        let config = IntralinksDocsRsConfig::default();
+
+        let link = documentation_url(&identifier("crate"), SymbolType::Crate, "foobini", &config);
         assert_eq!(link, "https://docs.rs/foobini/latest/foobini/");
 
-        let link = documentation_url(&identifier("crate::AStruct"), SymbolType::Struct, "foobini");
+        let link = documentation_url(
+            &identifier("crate::AStruct"),
+            SymbolType::Struct,
+            "foobini",
+            &config,
+        );
         assert_eq!(link, "https://docs.rs/foobini/latest/foobini/struct.AStruct.html");
 
-        let link = documentation_url(&identifier("crate::amodule"), SymbolType::Mod, "foobini");
+        let link =
+            documentation_url(&identifier("crate::amodule"), SymbolType::Mod, "foobini", &config);
         assert_eq!(link, "https://docs.rs/foobini/latest/foobini/amodule/");
 
-        let link = documentation_url(&identifier("::std"), SymbolType::Crate, "foobini");
+        let link = documentation_url(&identifier("::std"), SymbolType::Crate, "foobini", &config);
         assert_eq!(link, "https://doc.rust-lang.org/stable/std/");
 
         let link = documentation_url(
             &identifier("::std::collections::HashMap"),
             SymbolType::Struct,
             "foobini",
+            &config,
         );
         assert_eq!(link, "https://doc.rust-lang.org/stable/std/collections/struct.HashMap.html");
 
@@ -951,8 +1038,18 @@ mod tests {
             &FQIdentifier::from_string("crate::amodule").unwrap(),
             SymbolType::Mod,
             "foo-bar-mumble",
+            &config,
         );
         assert_eq!(link, "https://docs.rs/foo-bar-mumble/latest/foo_bar_mumble/amodule/");
+
+        let config = IntralinksDocsRsConfig {
+            docs_rs_base_url: Some("https://docs.company.rs".to_owned()),
+            docs_rs_version: Some("1.0.0".to_owned()),
+        };
+
+        let link =
+            documentation_url(&identifier("crate::Foo"), SymbolType::Struct, "foobini", &config);
+        assert_eq!(link, "https://docs.company.rs/foobini/1.0.0/foobini/struct.Foo.html");
     }
 
     #[test]
@@ -995,7 +1092,61 @@ mod tests {
             should [wor\\k \[fi\]le](f\\i\(n\)e).
 
             Go ahead and check all the [structs in foo](crate::foo#structs) specifically
-            [this one](crate::foo::BestStruct)
+            [this one](crate::foo::BestStruct).  Also, this is a nice function: [copy](::std::fs::copy).
+
+            [![BestStruct doc](https://example.com/image.png)](crate::foo::BestStruct)
+            "
+        };
+
+        let symbols_type: HashMap<FQIdentifier, SymbolType> = [
+            (identifier("crate"), SymbolType::Crate),
+            (identifier("crate::amodule"), SymbolType::Mod),
+            (identifier("crate::foo"), SymbolType::Mod),
+            (identifier("crate::foo::BestStruct"), SymbolType::Struct),
+            (identifier("::std::fs::copy"), SymbolType::Fn),
+        ]
+        .into_iter()
+        .collect();
+
+        let new_readme = rewrite_markdown_links(
+            &Doc::from_str(doc),
+            &symbols_type,
+            "foobini",
+            &mut |_| (),
+            &IntralinksConfig::default(),
+        );
+        let expected = indoc! { r"
+            # Foobini
+
+            This [beautiful crate](https://docs.rs/foobini/latest/foobini/) is cool because it contains [modules](https://docs.rs/foobini/latest/foobini/amodule/)
+            and some other [stuff](https://en.wikipedia.org/wiki/Stuff) as well.
+
+            This link is broken and this is not supported, but this
+            should [wor\\k \[fi\]le](f\\i\(n\)e).
+
+            Go ahead and check all the [structs in foo](https://docs.rs/foobini/latest/foobini/foo/#structs) specifically
+            [this one](https://docs.rs/foobini/latest/foobini/foo/struct.BestStruct.html).  Also, this is a nice function: [copy](https://doc.rust-lang.org/stable/std/fs/fn.copy.html).
+
+            [![BestStruct doc](https://example.com/image.png)](https://docs.rs/foobini/latest/foobini/foo/struct.BestStruct.html)
+            "
+        };
+
+        assert_eq!(new_readme.as_string(), expected);
+    }
+
+    #[test]
+    fn test_rewrite_markdown_links_strip_links() {
+        let doc = indoc! { r"
+            # Foobini
+
+            This [beautiful crate](crate) is cool because it contains [modules](crate::amodule)
+            and some other [stuff](https://en.wikipedia.org/wiki/Stuff) as well.
+
+            This link is [broken](crate::broken) and this is [not supported](::foo::bar), but this
+            should [wor\\k \[fi\]le](f\\i\(n\)e).
+
+            Go ahead and check all the [structs in foo](crate::foo#structs) specifically
+            [this one](crate::foo::BestStruct).  Also, this is a nice function: [copy](::std::fs::copy).
 
             [![BestStruct doc](https://example.com/image.png)](crate::foo::BestStruct)
             "
@@ -1010,21 +1161,26 @@ mod tests {
         .into_iter()
         .collect();
 
-        let new_readme =
-            rewrite_markdown_links(&Doc::from_str(doc), &symbols_type, "foobini", &mut |_| ());
+        let new_readme = rewrite_markdown_links(
+            &Doc::from_str(doc),
+            &symbols_type,
+            "foobini",
+            &mut |_| (),
+            &IntralinksConfig { strip_links: Some(true), ..std::default::Default::default() },
+        );
         let expected = indoc! { r"
             # Foobini
 
-            This [beautiful crate](https://docs.rs/foobini/latest/foobini/) is cool because it contains [modules](https://docs.rs/foobini/latest/foobini/amodule/)
+            This beautiful crate is cool because it contains modules
             and some other [stuff](https://en.wikipedia.org/wiki/Stuff) as well.
 
-            This link is [broken](crate::broken) and this is [not supported](::foo::bar), but this
+            This link is broken and this is not supported, but this
             should [wor\\k \[fi\]le](f\\i\(n\)e).
 
-            Go ahead and check all the [structs in foo](https://docs.rs/foobini/latest/foobini/foo/#structs) specifically
-            [this one](https://docs.rs/foobini/latest/foobini/foo/struct.BestStruct.html)
+            Go ahead and check all the structs in foo specifically
+            this one.  Also, this is a nice function: copy.
 
-            [![BestStruct doc](https://example.com/image.png)](https://docs.rs/foobini/latest/foobini/foo/struct.BestStruct.html)
+            ![BestStruct doc](https://example.com/image.png)
             "
         };
 
